@@ -150,7 +150,9 @@ impl MietteHandlerOpts {
                 None if supports_unicode::on(Stream::Stderr) => ThemeCharacters::unicode(),
                 None => ThemeCharacters::ascii(),
             };
-            let styles = if self.rgb_colors == Some(true) {
+            let styles = if self.color == Some(false) {
+                ThemeStyles::none()
+            } else if self.rgb_colors == Some(true) {
                 ThemeStyles::rgb()
             } else if self.ansi_colors == Some(true) {
                 ThemeStyles::ansi()
@@ -165,10 +167,11 @@ impl MietteHandlerOpts {
             } else {
                 ThemeStyles::none()
             };
+            let theme = self.theme.unwrap_or(GraphicalTheme { characters, styles });
             let mut handler = GraphicalReportHandler::new()
                 .with_width(width)
                 .with_links(linkify)
-                .with_theme(GraphicalTheme { characters, styles });
+                .with_theme(theme);
             if let Some(footer) = self.footer {
                 handler = handler.with_footer(footer);
             }
