@@ -1,9 +1,8 @@
 /*!
-This module defines the core of the miette protocol: a series of types and traits
-that you can implement to get access to miette's (and related library's) full
-reporting and such features.
+This module defines the core of the miette protocol: a series of types and
+traits that you can implement to get access to miette's (and related library's)
+full reporting and such features.
 */
-
 use std::{
     fmt::{self, Display},
     fs,
@@ -12,50 +11,51 @@ use std::{
 
 use crate::MietteError;
 
-/**
-Adds rich metadata to your Error that can be used by [Report] to print
-really nice and human-friendly error messages.
-*/
+/// Adds rich metadata to your Error that can be used by
+/// [`Report`](crate::Report) to print really nice and human-friendly error
+/// messages.
 pub trait Diagnostic: std::error::Error {
     /// Unique diagnostic code that can be used to look up more information
-    /// about this Diagnostic. Ideally also globally unique, and documented in
-    /// the toplevel crate's documentation for easy searching. Rust path
+    /// about this `Diagnostic`. Ideally also globally unique, and documented
+    /// in the toplevel crate's documentation for easy searching. Rust path
     /// format (`foo::bar::baz`) is recommended, but more classic codes like
-    /// `E0123` or Enums will work just fine.
+    /// `E0123` or enums will work just fine.
     fn code<'a>(&'a self) -> Option<Box<dyn Display + 'a>> {
         None
     }
 
-    /// Diagnostic severity. This may be used by [ReportHandler]s to change the
-    /// display format of this diagnostic.
+    /// Diagnostic severity. This may be used by
+    /// [`ReportHandler`](crate::ReportHandler)s to change the display format
+    /// of this diagnostic.
     ///
-    /// If `None`, reporters should treat this as [Severity::Error]
+    /// If `None`, reporters should treat this as [`Severity::Error`].
     fn severity(&self) -> Option<Severity> {
         None
     }
 
-    /// Additional help text related to this Diagnostic. Do you have any
+    /// Additional help text related to this `Diagnostic`. Do you have any
     /// advice for the poor soul who's just run into this issue?
     fn help<'a>(&'a self) -> Option<Box<dyn Display + 'a>> {
         None
     }
 
-    /// URL to visit for a more detailed explanation/help about this Diagnostic.
+    /// URL to visit for a more detailed explanation/help about this
+    /// `Diagnostic`.
     fn url<'a>(&'a self) -> Option<Box<dyn Display + 'a>> {
         None
     }
 
-    /// Source code to apply this Diagnostic's [Diagnostic::labels] to.
+    /// Source code to apply this `Diagnostic`'s [`Diagnostic::labels`] to.
     fn source_code(&self) -> Option<&dyn SourceCode> {
         None
     }
 
-    /// Labels to apply to this Diagnostic's [Diagnostic::source_code]
+    /// Labels to apply to this `Diagnostic`'s [`Diagnostic::source_code`]
     fn labels(&self) -> Option<Box<dyn Iterator<Item = LabeledSpan> + '_>> {
         None
     }
 
-    /// Additional related Diagnostics.
+    /// Additional related `Diagnostic`s.
     fn related<'a>(&'a self) -> Option<Box<dyn Iterator<Item = &'a dyn Diagnostic> + 'a>> {
         None
     }
@@ -153,8 +153,9 @@ impl From<Box<dyn std::error::Error + Send + Sync>> for Box<dyn Diagnostic + Sen
 }
 
 /**
-[Diagnostic] severity. Intended to be used by [ReportHandler]s to change the
-way different Diagnostics are displayed.
+[`Diagnostic`] severity. Intended to be used by
+[`ReportHandler`](crate::ReportHandler)s to change the way different
+[`Diagnostic`]s are displayed.
 */
 #[derive(Copy, Clone, Debug, Eq, PartialEq)]
 pub enum Severity {
@@ -169,13 +170,13 @@ pub enum Severity {
 /**
 Represents readable source code of some sort.
 
-This trait is able to support simple Source types like [String]s, as well
-as more involved types like indexes into centralized `SourceMap`-like types,
-file handles, and even network streams.
+This trait is able to support simple `SourceCode` types like [`String`]s, as
+well as more involved types like indexes into centralized `SourceMap`-like
+types, file handles, and even network streams.
 
-If you can read it, you can source it,
-and it's not necessary to read the whole thing--meaning you should be able to
-support SourceCodes which are gigabytes or larger in size.
+If you can read it, you can source it, and it's not necessary to read the
+whole thing--meaning you should be able to support `SourceCode`s which are
+gigabytes or larger in size.
 */
 pub trait SourceCode: Send + Sync {
     /// Read the bytes for a specific span from this SourceCode, keeping a
@@ -188,9 +189,7 @@ pub trait SourceCode: Send + Sync {
     ) -> Result<Box<dyn SpanContents<'a> + 'a>, MietteError>;
 }
 
-/**
-A labeled [SourceSpan].
-*/
+/// A labeled [`SourceSpan`].
 #[derive(Debug, Clone, PartialEq, Eq)]
 pub struct LabeledSpan {
     label: Option<String>,
@@ -214,12 +213,12 @@ impl LabeledSpan {
         }
     }
 
-    /// Gets the (optional) label string for this LabeledSpan.
+    /// Gets the (optional) label string for this `LabeledSpan`.
     pub fn label(&self) -> Option<&str> {
         self.label.as_deref()
     }
 
-    /// Returns a reference to the inner [SourceSpan].
+    /// Returns a reference to the inner [`SourceSpan`].
     pub fn inner(&self) -> &SourceSpan {
         &self.span
     }
@@ -229,52 +228,53 @@ impl LabeledSpan {
         self.span.offset()
     }
 
-    /// Returns the number of bytes this LabeledSpan spans.
+    /// Returns the number of bytes this `LabeledSpan` spans.
     pub fn len(&self) -> usize {
         self.span.len()
     }
 
-    /// True if this LabeledSpan is empty.
+    /// True if this `LabeledSpan` is empty.
     pub fn is_empty(&self) -> bool {
         self.span.is_empty()
     }
 }
 
 /**
-Contents of a [SourceCode] covered by [SourceSpan].
+Contents of a [`SourceCode`] covered by [`SourceSpan`].
 
 Includes line and column information to optimize highlight calculations.
 */
 pub trait SpanContents<'a> {
     /// Reference to the data inside the associated span, in bytes.
     fn data(&self) -> &'a [u8];
-    /// [SourceSpan] representing the span covered by this SpanContents.
+    /// [`SourceSpan`] representing the span covered by this `SpanContents`.
     fn span(&self) -> &SourceSpan;
-    /// An optional (file?) name for the container of this SpanContents.
+    /// An optional (file?) name for the container of this `SpanContents`.
     fn name(&self) -> Option<&str> {
         None
     }
-    /// The 0-indexed line in the associated [SourceCode] where the data begins.
+    /// The 0-indexed line in the associated [`SourceCode`] where the data
+    /// begins.
     fn line(&self) -> usize;
-    /// The 0-indexed column in the associated [SourceCode] where the data begins,
-    /// relative to `line`.
+    /// The 0-indexed column in the associated [`SourceCode`] where the data
+    /// begins, relative to `line`.
     fn column(&self) -> usize;
-    /// Total number of lines covered by this SpanContents.
+    /// Total number of lines covered by this `SpanContents`.
     fn line_count(&self) -> usize;
 }
 
 /**
-Basic implementation of the [SpanContents] trait, for convenience.
+Basic implementation of the [`SpanContents`] trait, for convenience.
 */
 #[derive(Clone, Debug)]
 pub struct MietteSpanContents<'a> {
-    // Data from a [SourceCode], in bytes.
+    // Data from a [`SourceCode`], in bytes.
     data: &'a [u8],
     // span actually covered by this SpanContents.
     span: SourceSpan,
-    // The 0-indexed line where the associated [SourceSpan] _starts_.
+    // The 0-indexed line where the associated [`SourceSpan`] _starts_.
     line: usize,
-    // The 0-indexed column where the associated [SourceSpan] _starts_.
+    // The 0-indexed column where the associated [`SourceSpan`] _starts_.
     column: usize,
     // Number of line in this snippet.
     line_count: usize,
@@ -283,7 +283,7 @@ pub struct MietteSpanContents<'a> {
 }
 
 impl<'a> MietteSpanContents<'a> {
-    /// Make a new [MietteSpanContents] object.
+    /// Make a new [`MietteSpanContents`] object.
     pub fn new(
         data: &'a [u8],
         span: SourceSpan,
@@ -301,7 +301,7 @@ impl<'a> MietteSpanContents<'a> {
         }
     }
 
-    /// Make a new [MietteSpanContents] object, with a name for its "file".
+    /// Make a new [`MietteSpanContents`] object, with a name for its 'file'.
     pub fn new_named(
         name: String,
         data: &'a [u8],
@@ -343,7 +343,7 @@ impl<'a> SpanContents<'a> for MietteSpanContents<'a> {
 }
 
 /**
-Span within a [SourceCode] with an associated message.
+Span within a [`SourceCode`] with an associated message.
 */
 #[derive(Clone, Debug, Eq, PartialEq, Hash)]
 pub struct SourceSpan {
@@ -354,7 +354,7 @@ pub struct SourceSpan {
 }
 
 impl SourceSpan {
-    /// Create a new [SourceSpan].
+    /// Create a new [`SourceSpan`].
     pub fn new(start: SourceOffset, length: SourceOffset) -> Self {
         Self {
             offset: start,
@@ -362,17 +362,17 @@ impl SourceSpan {
         }
     }
 
-    /// The absolute offset, in bytes, from the beginning of a [SourceCode].
+    /// The absolute offset, in bytes, from the beginning of a [`SourceCode`].
     pub fn offset(&self) -> usize {
         self.offset.offset()
     }
 
-    /// Total length of the [SourceSpan], in bytes.
+    /// Total length of the [`SourceSpan`], in bytes.
     pub fn len(&self) -> usize {
         self.length.offset()
     }
 
-    /// Whether this [SourceSpan] has a length of zero. It may still be useful
+    /// Whether this [`SourceSpan`] has a length of zero. It may still be useful
     /// to point to a specific point.
     pub fn is_empty(&self) -> bool {
         self.length.offset() == 0
@@ -407,12 +407,12 @@ impl From<std::ops::Range<ByteOffset>> for SourceSpan {
 }
 
 /**
-"Raw" type for the byte offset from the beginning of a [SourceCode].
+"Raw" type for the byte offset from the beginning of a [`SourceCode`].
 */
 pub type ByteOffset = usize;
 
 /**
-Newtype that represents the [ByteOffset] from the beginning of a [SourceCode]
+Newtype that represents the [`ByteOffset`] from the beginning of a [`SourceCode`]
 */
 #[derive(Clone, Copy, Debug, Eq, PartialEq, Hash)]
 pub struct SourceOffset(ByteOffset);
@@ -453,7 +453,7 @@ impl SourceOffset {
     /// function's caller with `#[track_caller]` (and so on and so forth).
     ///
     /// Returns both the filename that was given and the offset of the caller
-    /// as a SourceOffset
+    /// as a [`SourceOffset`].
     ///
     /// Keep in mind that this fill only work if the file your Rust source
     /// file was compiled from is actually available at that location. If
